package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.UserTypeMapper;
import com.ruoyi.system.domain.UserType;
import com.ruoyi.system.service.IUserTypeService;

/**
 * 系统角色Service业务层处理
 * 
 * @author haotian
 * @date 2024-11-18
 */
@Service
public class UserTypeServiceImpl implements IUserTypeService 
{
    @Autowired
    private UserTypeMapper userTypeMapper;

    /**
     * 查询系统角色
     * 
     * @param typeId 系统角色主键
     * @return 系统角色
     */
    @Override
    public UserType selectUserTypeByTypeId(Long typeId)
    {
        return userTypeMapper.selectUserTypeByTypeId(typeId);
    }

    /**
     * 查询系统角色列表
     * 
     * @param userType 系统角色
     * @return 系统角色
     */
    @Override
    public List<UserType> selectUserTypeList(UserType userType)
    {
        return userTypeMapper.selectUserTypeList(userType);
    }

    /**
     * 新增系统角色
     * 
     * @param userType 系统角色
     * @return 结果
     */
    @Override
    public int insertUserType(UserType userType)
    {
        userType.setCreateTime(DateUtils.getNowDate());
        return userTypeMapper.insertUserType(userType);
    }

    /**
     * 修改系统角色
     * 
     * @param userType 系统角色
     * @return 结果
     */
    @Override
    public int updateUserType(UserType userType)
    {
        userType.setUpdateTime(DateUtils.getNowDate());
        return userTypeMapper.updateUserType(userType);
    }

    /**
     * 批量删除系统角色
     * 
     * @param typeIds 需要删除的系统角色主键
     * @return 结果
     */
    @Override
    public int deleteUserTypeByTypeIds(Long[] typeIds)
    {
        return userTypeMapper.deleteUserTypeByTypeIds(typeIds);
    }

    /**
     * 删除系统角色信息
     * 
     * @param typeId 系统角色主键
     * @return 结果
     */
    @Override
    public int deleteUserTypeByTypeId(Long typeId)
    {
        return userTypeMapper.deleteUserTypeByTypeId(typeId);
    }
}
