package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.UserType;
import com.ruoyi.system.service.IUserTypeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 系统角色Controller
 * 
 * @author haotian
 * @date 2024-11-18
 */
@RestController
@RequestMapping("/system/type")
public class UserTypeController extends BaseController
{
    @Autowired
    private IUserTypeService userTypeService;

    /**
     * 查询系统角色列表
     */
    @PreAuthorize("@ss.hasPermi('system:type:list')")
    @GetMapping("/list")
    public TableDataInfo list(UserType userType)
    {
        startPage();
        List<UserType> list = userTypeService.selectUserTypeList(userType);
        return getDataTable(list);
    }

    /**
     * 导出系统角色列表
     */
    @PreAuthorize("@ss.hasPermi('system:type:export')")
    @Log(title = "系统角色", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, UserType userType)
    {
        List<UserType> list = userTypeService.selectUserTypeList(userType);
        ExcelUtil<UserType> util = new ExcelUtil<UserType>(UserType.class);
        util.exportExcel(response, list, "系统角色数据");
    }

    /**
     * 获取系统角色详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:type:query')")
    @GetMapping(value = "/{typeId}")
    public AjaxResult getInfo(@PathVariable("typeId") Long typeId)
    {
        return success(userTypeService.selectUserTypeByTypeId(typeId));
    }

    /**
     * 新增系统角色
     */
    @PreAuthorize("@ss.hasPermi('system:type:add')")
    @Log(title = "系统角色", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody UserType userType)
    {
        return toAjax(userTypeService.insertUserType(userType));
    }

    /**
     * 修改系统角色
     */
    @PreAuthorize("@ss.hasPermi('system:type:edit')")
    @Log(title = "系统角色", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody UserType userType)
    {
        return toAjax(userTypeService.updateUserType(userType));
    }

    /**
     * 删除系统角色
     */
    @PreAuthorize("@ss.hasPermi('system:type:remove')")
    @Log(title = "系统角色", businessType = BusinessType.DELETE)
	@DeleteMapping("/{typeIds}")
    public AjaxResult remove(@PathVariable Long[] typeIds)
    {
        return toAjax(userTypeService.deleteUserTypeByTypeIds(typeIds));
    }
}
